@@ -14,7 +14,6 @@ import oslo_messaging
 
 from oslo_config import cfg
 from oslo_context import context
-from oslo_policy import opts
 from oslo_policy import policy
 from pecan import hooks
 
@@ -26,12 +25,6 @@ from vitrage import storage
 
 CONF = cfg.CONF
 
-# TODO(gmann): Remove setting the default value of config policy_file
-# once oslo_policy change the default value to 'policy.yaml'.
-# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
-DEFAULT_POLICY_FILE = 'policy.yaml'
-opts.set_defaults(CONF, DEFAULT_POLICY_FILE)
-
 
 class ConfigHook(hooks.PecanHook):
     """Attach the configuration and policy enforcer object to the request. """
@@ -80,14 +73,14 @@ class ContextHook(hooks.PecanHook):
         user_id = state.request.headers.get('X-User-Id')
         user_id = state.request.headers.get('X-User', user_id)
         user_name = state.request.headers.get('X-User-Name', '')
-        tenant_id = state.request.headers.get('X-Project-Id')
+        project_id = state.request.headers.get('X-Project-Id')
         auth_token = state.request.headers.get('X-Auth-Token')
         # TODO(DANY) use roles
         # roles = pecan.request.headers.get('X-Roles', '').split(',')
         # roles = [r.strip() for r in roles]
         ctx = context.RequestContext(auth_token=auth_token, user=user_id,
                                      # roles=roles,
-                                     tenant=tenant_id,
+                                     project_id=project_id,
                                      is_admin=(user_name == 'admin'))
 
         # Inject the context...
